#
# PySNMP MIB module UDPLITE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/UDPLITE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:25 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( InetPortNumber, InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetPortNumber", "InetAddress", "InetAddressType")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( Bits, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, NotificationType, Counter32, Unsigned32, ModuleIdentity, Counter64, Gauge32, TimeTicks, ObjectIdentity, Integer32, mib_2, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "NotificationType", "Counter32", "Unsigned32", "ModuleIdentity", "Counter64", "Gauge32", "TimeTicks", "ObjectIdentity", "Integer32", "mib-2", "MibIdentifier")
( DisplayString, TimeStamp, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeStamp", "TextualConvention")
udpliteMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 170)).setRevisions(("2007-12-18 00:00",))
if mibBuilder.loadTexts: udpliteMIB.setLastUpdated('200712180000Z')
if mibBuilder.loadTexts: udpliteMIB.setOrganization('IETF TSV Working Group (TSVWG)')
if mibBuilder.loadTexts: udpliteMIB.setContactInfo('IETF TSV Working Group\n            http://www.ietf.org/html.charters/tsvwg-charter.html\n            Mailing List: tsvwg@ietf.org\n\n\n\n\n            Gerrit Renker, Godred Fairhurst\n            Electronics Research Group\n            School of Engineering, University of Aberdeen\n            Fraser Noble Building, Aberdeen AB24 3UE, UK')
if mibBuilder.loadTexts: udpliteMIB.setDescription('The MIB module for managing UDP-Lite implementations.\n            Copyright (C) The IETF Trust (2008).  This version of\n            this MIB module is part of RFC 5097; see the RFC\n            itself for full legal notices.')
udplite = MibIdentifier((1, 3, 6, 1, 2, 1, 170, 1))
udpliteInDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 1), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteInDatagrams.setDescription('The total number of UDP-Lite datagrams that were\n            delivered to UDP-Lite users.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteInPartialCov = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteInPartialCov.setDescription('The total number of UDP-Lite datagrams that were\n            delivered to UDP-Lite users (applications) and whose\n            checksum coverage was strictly less than the datagram\n            length.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteNoPorts = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteNoPorts.setDescription('The total number of received UDP-Lite datagrams for\n            which there was no listener at the destination port.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteInErrors = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteInErrors.setDescription('The number of received UDP-Lite datagrams that could not\n            be delivered for reasons other than the lack of an\n            application at the destination port.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteInBadChecksum = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteInBadChecksum.setDescription('The number of received UDP-Lite datagrams whose checksum\n            could not be validated.  This includes illegal checksum\n            coverage values, as their use would lead to incorrect\n            checksums.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteOutDatagrams = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 6), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteOutDatagrams.setDescription('The total number of UDP-Lite datagrams sent from this\n            entity.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteOutPartialCov = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 7), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteOutPartialCov.setDescription('The total number of udpliteOutDatagrams whose\n            checksum coverage was strictly less than the\n            datagram length.\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteEndpointTable = MibTable((1, 3, 6, 1, 2, 1, 170, 1, 8), )
if mibBuilder.loadTexts: udpliteEndpointTable.setDescription("A table containing information about this entity's\n            UDP-Lite endpoints on which a local application is\n            currently accepting or sending datagrams.\n\n            The address type in this table represents the address\n            type used for the communication, irrespective of the\n            higher-layer abstraction.  For example, an application\n            using IPv6 'sockets' to communicate via IPv4 between\n            ::ffff:10.0.0.1 and ::ffff:10.0.0.2 would use\n            InetAddressType ipv4(1).\n\n            Like the udpTable in RFC 4113, this table also allows\n            the representation of an application that completely\n            specifies both local and remote addresses and ports.  A\n            listening application is represented in three possible\n            ways:\n\n            1) An application that is willing to accept both IPv4\n               and IPv6 datagrams is represented by a\n               udpliteEndpointLocalAddressType of unknown(0) and a\n               udpliteEndpointLocalAddress of ''h (a zero-length\n\n\n\n               octet-string).\n\n            2) An application that is willing to accept only IPv4\n               or only IPv6 datagrams is represented by a\n               udpliteEndpointLocalAddressType of the appropriate\n               address type and a udpliteEndpointLocalAddress of\n               '0.0.0.0' or '::' respectively.\n\n            3) An application that is listening for datagrams only\n               for a specific IP address but from any remote\n               system is represented by a\n               udpliteEndpointLocalAddressType of the appropriate\n               address type, with udpliteEndpointLocalAddress\n               specifying the local address.\n\n            In all cases where the remote address is a wildcard,\n            the udpliteEndpointRemoteAddressType is unknown(0),\n            the udpliteEndpointRemoteAddress is ''h (a zero-length\n            octet-string), and the udpliteEndpointRemotePort is 0.\n\n            If the operating system is demultiplexing UDP-Lite\n            packets by remote address/port, or if the application\n            has 'connected' the socket specifying a default remote\n            address/port, the udpliteEndpointRemote* values should\n            be used to reflect this.")
udpliteEndpointEntry = MibTableRow((1, 3, 6, 1, 2, 1, 170, 1, 8, 1), ).setIndexNames((0, "UDPLITE-MIB", "udpliteEndpointLocalAddressType"), (0, "UDPLITE-MIB", "udpliteEndpointLocalAddress"), (0, "UDPLITE-MIB", "udpliteEndpointLocalPort"), (0, "UDPLITE-MIB", "udpliteEndpointRemoteAddressType"), (0, "UDPLITE-MIB", "udpliteEndpointRemoteAddress"), (0, "UDPLITE-MIB", "udpliteEndpointRemotePort"), (0, "UDPLITE-MIB", "udpliteEndpointInstance"))
if mibBuilder.loadTexts: udpliteEndpointEntry.setDescription('Information about a particular current UDP-Lite endpoint.\n            Implementers need to pay attention to the sizes of\n            udpliteEndpointLocalAddress/RemoteAddress, as Object\n            Identifiers (OIDs) of column instances in this table must\n            have no more than 128 sub-identifiers in order to remain\n             accessible with SNMPv1, SNMPv2c, and SNMPv3.')
udpliteEndpointLocalAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 1), InetAddressType())
if mibBuilder.loadTexts: udpliteEndpointLocalAddressType.setDescription('The address type of udpliteEndpointLocalAddress.  Only\n            IPv4, IPv4z, IPv6, and IPv6z addresses are expected, or\n            unknown(0) if datagrams for all local IP addresses are\n            accepted.')
udpliteEndpointLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 2), InetAddress())
if mibBuilder.loadTexts: udpliteEndpointLocalAddress.setDescription("The local IP address for this UDP-Lite endpoint.\n\n            The value of this object can be represented in three\n            possible ways, depending on the characteristics of the\n            listening application:\n\n            1. For an application that is willing to accept both\n               IPv4 and IPv6 datagrams, the value of this object\n               must be ''h (a zero-length octet-string), with\n               the value of the corresponding instance of the\n               EndpointLocalAddressType object being unknown(0).\n\n            2. For an application that is willing to accept only\n               IPv4 or only IPv6 datagrams, the value of this\n               object must be '0.0.0.0' or '::', respectively,\n               while the corresponding instance of the\n               EndpointLocalAddressType object represents the\n               appropriate address type.\n\n            3. For an application that is listening for data\n\n\n\n               destined only to a specific IP address, the value\n               of this object is the specific IP address for\n               which this node is receiving packets, with the\n               corresponding instance of the\n               EndpointLocalAddressType object representing the\n               appropriate address type.\n\n            As this object is used in the index for the\n            udpliteEndpointTable, implementors should be careful\n            not to create entries that would result in OIDs with\n            more than 128 sub-identifiers; this is because of SNMP\n            and SMI limitations.")
udpliteEndpointLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 3), InetPortNumber())
if mibBuilder.loadTexts: udpliteEndpointLocalPort.setDescription('The local port number for this UDP-Lite endpoint.')
udpliteEndpointRemoteAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 4), InetAddressType())
if mibBuilder.loadTexts: udpliteEndpointRemoteAddressType.setDescription('The address type of udpliteEndpointRemoteAddress.  Only\n            IPv4, IPv4z, IPv6, and IPv6z addresses are expected, or\n            unknown(0) if datagrams for all remote IP addresses are\n            accepted.  Also, note that some combinations of\n            udpliteEndpointLocalAdressType and\n            udpliteEndpointRemoteAddressType are not supported.  In\n            particular, if the value of this object is not\n            unknown(0), it is expected to always refer to the\n            same IP version as udpliteEndpointLocalAddressType.')
udpliteEndpointRemoteAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 5), InetAddress())
if mibBuilder.loadTexts: udpliteEndpointRemoteAddress.setDescription("The remote IP address for this UDP-Lite endpoint.  If\n            datagrams from any remote system are to be accepted,\n            this value is ''h (a zero-length octet-string).\n            Otherwise, it has the type described by\n            udpliteEndpointRemoteAddressType and is the address of\n\n\n\n            the remote system from which datagrams are to be\n            accepted (or to which all datagrams will be sent).\n\n            As this object is used in the index for the\n            udpliteEndpointTable, implementors should be careful\n            not to create entries that would result in OIDs with\n            more than 128 sub-identifiers; this is because of SNMP\n            and SMI limitations.")
udpliteEndpointRemotePort = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 6), InetPortNumber())
if mibBuilder.loadTexts: udpliteEndpointRemotePort.setDescription('The remote port number for this UDP-Lite endpoint.  If\n            datagrams from any remote system are to be accepted,\n            this value is zero.')
udpliteEndpointInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 7), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: udpliteEndpointInstance.setDescription("The instance of this tuple.  This object is used to\n            distinguish among multiple processes 'connected' to\n            the same UDP-Lite endpoint.  For example, on a system\n            implementing the BSD sockets interface, this would be\n            used to support the SO_REUSEADDR and SO_REUSEPORT\n            socket options.")
udpliteEndpointProcess = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 8), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteEndpointProcess.setDescription("A unique value corresponding to a piece of software\n            running on this endpoint.\n\n            If this endpoint is associated with more than one piece\n            of software, the agent should choose one of these.  As\n            long as the representative piece of software\n            is running and still associated with the endpoint,\n            subsequent reads will consistently return the same\n            value.  The implementation may use any algorithm\n            satisfying these constraints (e.g., choosing the entity\n\n\n\n            with the oldest start time).\n\n            This identifier is platform-specific.  Wherever possible,\n            it should use the system's native, unique identification\n            number as the value.\n\n            If the SYSAPPL-MIB module is available, the value should\n            be the same as sysApplElmtRunIndex.  If not available, an\n            alternative should be used (e.g., the hrSWRunIndex of the\n            HOST-RESOURCES-MIB module).\n\n            If it is not possible to uniquely identify the pieces of\n            software associated with this endpoint, then the value\n            zero should be used.  (Note that zero is otherwise a\n            valid value for sysApplElmtRunIndex.)")
udpliteEndpointMinCoverage = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 9), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteEndpointMinCoverage.setDescription('The minimum checksum coverage expected by this endpoint.\n            A value of 0 indicates that only fully covered datagrams\n            are accepted.')
udpliteEndpointViolCoverage = MibTableColumn((1, 3, 6, 1, 2, 1, 170, 1, 8, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteEndpointViolCoverage.setDescription('The number of datagrams received by this endpoint whose\n            checksum coverage violated the minimum coverage threshold\n            set for this connection (i.e., all valid datagrams whose\n            checksum coverage was strictly smaller than the minimum,\n            as defined in RFC 3828).\n            Discontinuities in the value of this counter can occur\n            at re-initialisation of the management system, and at\n            other times as indicated by the value of\n            udpliteStatsDiscontinuityTime.')
udpliteStatsDiscontinuityTime = MibScalar((1, 3, 6, 1, 2, 1, 170, 1, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: udpliteStatsDiscontinuityTime.setDescription('The value of sysUpTime at the most recent occasion at\n            which one or more of the UDP-Lite counters suffered a\n            discontinuity.\n            A value of zero indicates no such discontinuity has\n            occurred since the last re-initialisation of the local\n            management subsystem.')
udpliteMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 170, 2))
udpliteMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 170, 2, 1)).setObjects(*(("UDPLITE-MIB", "udpliteBaseGroup"), ("UDPLITE-MIB", "udplitePartialCsumGroup"), ("UDPLITE-MIB", "udpliteEndpointGroup"), ("UDPLITE-MIB", "udpliteAppGroup"),))
if mibBuilder.loadTexts: udpliteMIBCompliance.setDescription('The compliance statement for systems that implement\n            UDP-Lite.\n\n            There are a number of INDEX objects that cannot be\n            represented in the form of OBJECT clauses in SMIv2,\n            but for which we have the following compliance\n            requirements, expressed in OBJECT clause form in this\n            description clause:\n\n            -- OBJECT      udpliteEndpointLocalAddressType\n            -- SYNTAX      InetAddressType { unknown(0), ipv4(1),\n            --                               ipv6(2), ipv4z(3),\n            --                               ipv6z(4) }\n            -- DESCRIPTION\n            --     Support for dns(16) is not required.\n            -- OBJECT      udpliteEndpointLocalAddress\n            -- SYNTAX      InetAddress (SIZE(0|4|8|16|20))\n            -- DESCRIPTION\n            --     Support is only required for zero-length\n            --     octet-strings, and for scoped and unscoped\n            --     IPv4 and IPv6 addresses.\n            -- OBJECT      udpliteEndpointRemoteAddressType\n            -- SYNTAX      InetAddressType { unknown(0), ipv4(1),\n            --                               ipv6(2), ipv4z(3),\n            --                               ipv6z(4) }\n            -- DESCRIPTION\n            --     Support for dns(16) is not required.\n            -- OBJECT      udpliteEndpointRemoteAddress\n\n\n\n            -- SYNTAX      InetAddress (SIZE(0|4|8|16|20))\n            -- DESCRIPTION\n            --     Support is only required for zero-length\n            --     octet-strings, and for scoped and unscoped\n            --     IPv4 and IPv6 addresses.\n           ')
udpliteMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 170, 2, 2))
udpliteBaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 170, 2, 2, 1)).setObjects(*(("UDPLITE-MIB", "udpliteInDatagrams"), ("UDPLITE-MIB", "udpliteNoPorts"), ("UDPLITE-MIB", "udpliteInErrors"), ("UDPLITE-MIB", "udpliteOutDatagrams"), ("UDPLITE-MIB", "udpliteStatsDiscontinuityTime"),))
if mibBuilder.loadTexts: udpliteBaseGroup.setDescription('The group of objects providing for counters of\n            basic UDP-like statistics.')
udplitePartialCsumGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 170, 2, 2, 2)).setObjects(*(("UDPLITE-MIB", "udpliteInPartialCov"), ("UDPLITE-MIB", "udpliteInBadChecksum"), ("UDPLITE-MIB", "udpliteOutPartialCov"),))
if mibBuilder.loadTexts: udplitePartialCsumGroup.setDescription('The group of objects providing for counters of\n            transport layer statistics exclusive to UDP-Lite.')
udpliteEndpointGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 170, 2, 2, 3)).setObjects(*(("UDPLITE-MIB", "udpliteEndpointProcess"), ("UDPLITE-MIB", "udpliteEndpointMinCoverage"),))
if mibBuilder.loadTexts: udpliteEndpointGroup.setDescription("The group of objects providing for the IP version\n            independent management of UDP-Lite 'endpoints'.")
udpliteAppGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 170, 2, 2, 4)).setObjects(*(("UDPLITE-MIB", "udpliteEndpointViolCoverage"),))
if mibBuilder.loadTexts: udpliteAppGroup.setDescription("The group of objects that provide application-level\n            information for the configuration management of\n            UDP-Lite 'endpoints'.")
mibBuilder.exportSymbols("UDPLITE-MIB", udpliteAppGroup=udpliteAppGroup, udplitePartialCsumGroup=udplitePartialCsumGroup, udpliteInPartialCov=udpliteInPartialCov, udpliteOutDatagrams=udpliteOutDatagrams, udpliteEndpointMinCoverage=udpliteEndpointMinCoverage, udpliteInBadChecksum=udpliteInBadChecksum, udpliteEndpointGroup=udpliteEndpointGroup, udpliteEndpointInstance=udpliteEndpointInstance, udpliteEndpointLocalAddress=udpliteEndpointLocalAddress, udpliteBaseGroup=udpliteBaseGroup, udpliteMIBCompliance=udpliteMIBCompliance, udpliteEndpointTable=udpliteEndpointTable, udpliteEndpointRemotePort=udpliteEndpointRemotePort, udpliteInDatagrams=udpliteInDatagrams, udpliteNoPorts=udpliteNoPorts, udpliteEndpointRemoteAddress=udpliteEndpointRemoteAddress, udpliteMIBGroups=udpliteMIBGroups, udpliteEndpointViolCoverage=udpliteEndpointViolCoverage, udpliteEndpointLocalAddressType=udpliteEndpointLocalAddressType, udpliteEndpointEntry=udpliteEndpointEntry, udpliteOutPartialCov=udpliteOutPartialCov, udpliteMIB=udpliteMIB, udpliteInErrors=udpliteInErrors, udpliteEndpointRemoteAddressType=udpliteEndpointRemoteAddressType, udpliteMIBConformance=udpliteMIBConformance, PYSNMP_MODULE_ID=udpliteMIB, udpliteEndpointLocalPort=udpliteEndpointLocalPort, udplite=udplite, udpliteEndpointProcess=udpliteEndpointProcess, udpliteStatsDiscontinuityTime=udpliteStatsDiscontinuityTime)



#
# PySNMP MIB module ROHC-UNCOMPRESSED-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ROHC-UNCOMPRESSED-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:12 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( rohcContextCID, rohcChannelID, ) = mibBuilder.importSymbols("ROHC-MIB", "rohcContextCID", "rohcChannelID")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Counter32, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Gauge32, Integer32, NotificationType, Unsigned32, iso, mib_2, TimeTicks, ObjectIdentity, IpAddress, Counter64, ModuleIdentity, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Gauge32", "Integer32", "NotificationType", "Unsigned32", "iso", "mib-2", "TimeTicks", "ObjectIdentity", "IpAddress", "Counter64", "ModuleIdentity", "MibIdentifier")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
rohcUncmprMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 113)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: rohcUncmprMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: rohcUncmprMIB.setOrganization('IETF Robust Header Compression Working Group')
if mibBuilder.loadTexts: rohcUncmprMIB.setContactInfo('WG charter:\n          http://www.ietf.org/html.charters/rohc-charter.html\n\n        Mailing Lists:\n          General Discussion: rohc@ietf.org\n          To Subscribe: rohc-request@ietf.org\n          In Body: subscribe your_email_address\n\n        Editor:\n          Juergen Quittek\n          NEC Europe Ltd.\n          Network Laboratories\n          Kurfuersten-Anlage 36\n          69221 Heidelberg\n          Germany\n          Tel: +49 6221 90511-15\n          EMail: quittek@netlab.nec.de')
if mibBuilder.loadTexts: rohcUncmprMIB.setDescription('This MIB module defines a set of objects for monitoring\n         and configuring RObust Header Compression (ROHC).\n         The objects are specific to ROHC uncompressed\n         (profile 0x0000).\n\n         Copyright (C) The Internet Society (2004). The\n         initial version of this MIB module was published\n         in RFC 3816. For full legal notices see the RFC\n         itself or see:\n         http://www.ietf.org/copyrights/ianamib.html')
rohcUncmprObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 113, 1))
rohcUncmprConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 113, 2))
rohcUncmprContextTable = MibTable((1, 3, 6, 1, 2, 1, 113, 1, 1), )
if mibBuilder.loadTexts: rohcUncmprContextTable.setDescription('This table lists and describes ROHC uncompressed profile\n         specific properties of compressor contexts and\n         decompressor contexts.  It extends the rohcContextTable\n         of the ROHC-MIB module.')
rohcUncmprContextEntry = MibTableRow((1, 3, 6, 1, 2, 1, 113, 1, 1, 1), ).setIndexNames((0, "ROHC-MIB", "rohcChannelID"), (0, "ROHC-MIB", "rohcContextCID"))
if mibBuilder.loadTexts: rohcUncmprContextEntry.setDescription('An entry describing a particular context.')
rohcUncmprContextState = MibTableColumn((1, 3, 6, 1, 2, 1, 113, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("initAndRefresh", 1), ("normal", 2), ("noContext", 3), ("fullContext", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcUncmprContextState.setDescription('State of the context. States initAndRefresh(1) and normal(2)\n         are states of compressor contexts, states noContext(3)\n         and fullContext(4) are states of decompressor contexts.')
rohcUncmprContextMode = MibTableColumn((1, 3, 6, 1, 2, 1, 113, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("unidirectional", 1), ("bidirectional", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcUncmprContextMode.setDescription('Mode of the context.')
rohcUncmprContextACKs = MibTableColumn((1, 3, 6, 1, 2, 1, 113, 1, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcUncmprContextACKs.setDescription('The number of all positive feedbacks (ACK) sent or\n         received in this context, respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.')
rohcUncmprCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 113, 2, 1))
rohcUncmprGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 113, 2, 2))
rohcUncmprCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 113, 2, 1, 1)).setObjects(*(("ROHC-UNCOMPRESSED-MIB", "rohcUncmprContextGroup"), ("ROHC-UNCOMPRESSED-MIB", "rohcUncmprStatisticsGroup"),))
if mibBuilder.loadTexts: rohcUncmprCompliance.setDescription('The compliance statement for SNMP entities that implement\n         the ROHC-UNCOMPRESSED-MIB.\n\n         Note that compliance with this compliance\n         statement requires compliance with the\n         rohcCompliance MODULE-COMPLIANCE statement of the\n         ROHC-MIB and with the ifCompliance3 MODULE-COMPLIANCE\n         statement of the IF-MIB (RFC2863).')
rohcUncmprContextGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 113, 2, 2, 1)).setObjects(*(("ROHC-UNCOMPRESSED-MIB", "rohcUncmprContextState"), ("ROHC-UNCOMPRESSED-MIB", "rohcUncmprContextMode"),))
if mibBuilder.loadTexts: rohcUncmprContextGroup.setDescription('A collection of objects providing information about\n         ROHC uncompressed compressors and decompressors.')
rohcUncmprStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 113, 2, 2, 2)).setObjects(*(("ROHC-UNCOMPRESSED-MIB", "rohcUncmprContextACKs"),))
if mibBuilder.loadTexts: rohcUncmprStatisticsGroup.setDescription('An object providing context statistics.')
mibBuilder.exportSymbols("ROHC-UNCOMPRESSED-MIB", rohcUncmprCompliances=rohcUncmprCompliances, rohcUncmprObjects=rohcUncmprObjects, rohcUncmprContextTable=rohcUncmprContextTable, rohcUncmprContextState=rohcUncmprContextState, rohcUncmprContextMode=rohcUncmprContextMode, rohcUncmprContextACKs=rohcUncmprContextACKs, PYSNMP_MODULE_ID=rohcUncmprMIB, rohcUncmprContextEntry=rohcUncmprContextEntry, rohcUncmprGroups=rohcUncmprGroups, rohcUncmprStatisticsGroup=rohcUncmprStatisticsGroup, rohcUncmprContextGroup=rohcUncmprContextGroup, rohcUncmprConformance=rohcUncmprConformance, rohcUncmprCompliance=rohcUncmprCompliance, rohcUncmprMIB=rohcUncmprMIB)



#
# PySNMP MIB module DNS-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DNS-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:08:40 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( IpAddress, iso, Counter32, ObjectIdentity, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, NotificationType, Unsigned32, mib_2, Integer32, Gauge32, ModuleIdentity, TimeTicks, MibIdentifier, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "iso", "Counter32", "ObjectIdentity", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "NotificationType", "Unsigned32", "mib-2", "Integer32", "Gauge32", "ModuleIdentity", "TimeTicks", "MibIdentifier")
( TruthValue, TextualConvention, RowStatus, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "TextualConvention", "RowStatus", "DisplayString")
dns = ObjectIdentity((1, 3, 6, 1, 2, 1, 32))
if mibBuilder.loadTexts: dns.setDescription('The OID assigned to DNS MIB work by the IANA.')
dnsServMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 32, 1))
if mibBuilder.loadTexts: dnsServMIB.setLastUpdated('9401282251Z')
if mibBuilder.loadTexts: dnsServMIB.setOrganization('IETF DNS Working Group')
if mibBuilder.loadTexts: dnsServMIB.setContactInfo('       Rob Austein\n               Postal: Epilogue Technology Corporation\n                       268 Main Street, Suite 283\n                       North Reading, MA 10864\n                       US\n                  Tel: +1 617 245 0804\n                  Fax: +1 617 245 8122\n               E-Mail: sra@epilogue.com\n\n                       Jon Saperia\n               Postal: Digital Equipment Corporation\n                       110 Spit Brook Road\n                       ZKO1-3/H18\n                       Nashua, NH 03062-2698\n                       US\n                  Tel: +1 603 881 0480\n                  Fax: +1 603 881 0120\n                Email: saperia@zko.dec.com')
if mibBuilder.loadTexts: dnsServMIB.setDescription('The MIB module for entities implementing the server side\n               of the Domain Name System (DNS) protocol.')
dnsServMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 1))
dnsServConfig = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 1, 1))
dnsServCounter = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 1, 2))
dnsServOptCounter = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 1, 3))
dnsServZone = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 1, 4))
class DnsName(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class DnsNameAsIndex(DnsName, TextualConvention):
    pass

class DnsClass(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsType(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsQClass(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsQType(Integer32, TextualConvention):
    displayHint = '2d'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class DnsTime(Gauge32, TextualConvention):
    displayHint = '4d'

class DnsOpCode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,15)

class DnsRespCode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,15)

dnsServConfigImplementIdent = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 1, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServConfigImplementIdent.setDescription("The implementation identification string for the DNS\n               server software in use on the system, for example;\n               `FNS-2.1'")
dnsServConfigRecurs = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("available", 1), ("restricted", 2), ("unavailable", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsServConfigRecurs.setDescription('This represents the recursion services offered by this\n               name server.  The values that can be read or written\n               are:\n\n               available(1) - performs recursion on requests from\n               clients.\n\n               restricted(2) - recursion is performed on requests only\n               from certain clients, for example; clients on an access\n               control list.\n\n               unavailable(3) - recursion is not available.')
dnsServConfigUpTime = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 1, 3), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServConfigUpTime.setDescription('If the server has a persistent state (e.g., a process),\n               this value will be the time elapsed since it started.\n               For software without persistant state, this value will\n               be zero.')
dnsServConfigResetTime = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 1, 4), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServConfigResetTime.setDescription("If the server has a persistent state (e.g., a process)\n               and supports a `reset' operation (e.g., can be told to\n               re-read configuration files), this value will be the\n               time elapsed since the last time the name server was\n               `reset.'  For software that does not have persistence or\n               does not support a `reset' operation, this value will be\n               zero.")
dnsServConfigReset = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("reset", 2), ("initializing", 3), ("running", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dnsServConfigReset.setDescription('Status/action object to reinitialize any persistant name\n               server state.  When set to reset(2), any persistant\n               name server state (such as a process) is reinitialized as\n               if the name server had just been started.  This value\n               will never be returned by a read operation.  When read,\n               one of the following values will be returned:\n                   other(1) - server in some unknown state;\n                   initializing(3) - server (re)initializing;\n                   running(4) - server currently running.')
dnsServCounterAuthAns = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterAuthAns.setDescription('Number of queries which were authoritatively answered.')
dnsServCounterAuthNoNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterAuthNoNames.setDescription("Number of queries for which `authoritative no such name'\n               responses were made.")
dnsServCounterAuthNoDataResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterAuthNoDataResps.setDescription("Number of queries for which `authoritative no such data'\n               (empty answer) responses were made.")
dnsServCounterNonAuthDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterNonAuthDatas.setDescription('Number of queries which were non-authoritatively\n               answered (cached data).')
dnsServCounterNonAuthNoDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterNonAuthNoDatas.setDescription('Number of queries which were non-authoritatively\n               answered with no data (empty answer).')
dnsServCounterReferrals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterReferrals.setDescription('Number of requests that were referred to other servers.')
dnsServCounterErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterErrors.setDescription('Number of requests the server has processed that were\n               answered with errors (RCODE values other than 0 and 3).')
dnsServCounterRelNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterRelNames.setDescription('Number of requests received by the server for names that\n               are only 1 label long (text form - no internal dots).')
dnsServCounterReqRefusals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterReqRefusals.setDescription('Number of DNS requests refused by the server.')
dnsServCounterReqUnparses = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterReqUnparses.setDescription('Number of requests received which were unparseable.')
dnsServCounterOtherErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterOtherErrors.setDescription('Number of requests which were aborted for other (local)\n               server errors.')
dnsServCounterTable = MibTable((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13), )
if mibBuilder.loadTexts: dnsServCounterTable.setDescription('Counter information broken down by DNS class and type.')
dnsServCounterEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1), ).setIndexNames((0, "DNS-SERVER-MIB", "dnsServCounterOpCode"), (0, "DNS-SERVER-MIB", "dnsServCounterQClass"), (0, "DNS-SERVER-MIB", "dnsServCounterQType"), (0, "DNS-SERVER-MIB", "dnsServCounterTransport"))
if mibBuilder.loadTexts: dnsServCounterEntry.setDescription("This table contains count information for each DNS class\n               and type value known to the server.  The index allows\n               management software to to create indices to the table to\n               get the specific information desired, e.g., number of\n               queries over UDP for records with type value `A' which\n               came to this server.  In order to prevent an\n               uncontrolled expansion of rows in the table; if\n               dnsServCounterRequests is 0 and dnsServCounterResponses\n               is 0, then the row does not exist and `no such' is\n               returned when the agent is queried for such instances.")
dnsServCounterOpCode = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 1), DnsOpCode())
if mibBuilder.loadTexts: dnsServCounterOpCode.setDescription('The DNS OPCODE being counted in this row of the table.')
dnsServCounterQClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 2), DnsClass())
if mibBuilder.loadTexts: dnsServCounterQClass.setDescription('The class of record being counted in this row of the\n               table.')
dnsServCounterQType = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 3), DnsType())
if mibBuilder.loadTexts: dnsServCounterQType.setDescription('The type of record which is being counted in this row in\n               the table.')
dnsServCounterTransport = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("udp", 1), ("tcp", 2), ("other", 3),)))
if mibBuilder.loadTexts: dnsServCounterTransport.setDescription('A value of udp(1) indicates that the queries reported on\n               this row were sent using UDP.\n\n               A value of tcp(2) indicates that the queries reported on\n               this row were sent using TCP.\n\n               A value of other(3) indicates that the queries reported\n               on this row were sent using a transport that was neither\n               TCP nor UDP.')
dnsServCounterRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterRequests.setDescription('Number of requests (queries) that have been recorded in\n               this row of the table.')
dnsServCounterResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 2, 13, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServCounterResponses.setDescription('Number of responses made by the server since\n               initialization for the kind of query identified on this\n               row of the table.')
dnsServOptCounterSelfAuthAns = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfAuthAns.setDescription('Number of requests the server has processed which\n               originated from a resolver on the same host for which\n               there has been an authoritative answer.')
dnsServOptCounterSelfAuthNoNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfAuthNoNames.setDescription('Number of requests the server has processed which\n               originated from a resolver on the same host for which\n               there has been an authoritative no such name answer\n               given.')
dnsServOptCounterSelfAuthNoDataResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfAuthNoDataResps.setDescription('Number of requests the server has processed which\n               originated from a resolver on the same host for which\n               there has been an authoritative no such data answer\n               (empty answer) made.')
dnsServOptCounterSelfNonAuthDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfNonAuthDatas.setDescription('Number of requests the server has processed which\n               originated from a resolver on the same host for which a\n               non-authoritative answer (cached data) was made.')
dnsServOptCounterSelfNonAuthNoDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfNonAuthNoDatas.setDescription("Number of requests the server has processed which\n               originated from a resolver on the same host for which a\n               `non-authoritative, no such data' response was made\n               (empty answer).")
dnsServOptCounterSelfReferrals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfReferrals.setDescription('Number of queries the server has processed which\n               originated from a resolver on the same host and were\n               referred to other servers.')
dnsServOptCounterSelfErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfErrors.setDescription('Number of requests the server has processed which\n               originated from a resolver on the same host which have\n               been answered with errors (RCODEs other than 0 and 3).')
dnsServOptCounterSelfRelNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfRelNames.setDescription('Number of requests received for names that are only 1\n               label long (text form - no internal dots) the server has\n               processed which originated from a resolver on the same\n               host.')
dnsServOptCounterSelfReqRefusals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfReqRefusals.setDescription('Number of DNS requests refused by the server which\n               originated from a resolver on the same host.')
dnsServOptCounterSelfReqUnparses = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfReqUnparses.setDescription('Number of requests received which were unparseable and\n               which originated from a resolver on the same host.')
dnsServOptCounterSelfOtherErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterSelfOtherErrors.setDescription('Number of requests which were aborted for other (local)\n               server errors and which originated on the same host.')
dnsServOptCounterFriendsAuthAns = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsAuthAns.setDescription('Number of queries originating from friends which were\n               authoritatively answered.  The definition of friends is\n               a locally defined matter.')
dnsServOptCounterFriendsAuthNoNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsAuthNoNames.setDescription("Number of queries originating from friends, for which\n               authoritative `no such name' responses were made.  The\n               definition of friends is a locally defined matter.")
dnsServOptCounterFriendsAuthNoDataResps = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsAuthNoDataResps.setDescription('Number of queries originating from friends for which\n               authoritative no such data (empty answer) responses were\n               made.  The definition of friends is a locally defined\n               matter.')
dnsServOptCounterFriendsNonAuthDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsNonAuthDatas.setDescription('Number of queries originating from friends which were\n               non-authoritatively answered (cached data). The\n               definition of friends is a locally defined matter.')
dnsServOptCounterFriendsNonAuthNoDatas = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsNonAuthNoDatas.setDescription('Number of queries originating from friends which were\n               non-authoritatively answered with no such data (empty\n               answer).')
dnsServOptCounterFriendsReferrals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsReferrals.setDescription('Number of requests which originated from friends that\n               were referred to other servers.  The definition of\n               friends is a locally defined matter.')
dnsServOptCounterFriendsErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsErrors.setDescription('Number of requests the server has processed which\n               originated from friends and were answered with errors\n               (RCODE values other than 0 and 3).  The definition of\n               friends is a locally defined matter.')
dnsServOptCounterFriendsRelNames = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsRelNames.setDescription('Number of requests received for names from friends that\n               are only 1 label long (text form - no internal dots) the\n               server has processed.')
dnsServOptCounterFriendsReqRefusals = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsReqRefusals.setDescription("Number of DNS requests refused by the server which were\n               received from `friends'.")
dnsServOptCounterFriendsReqUnparses = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsReqUnparses.setDescription("Number of requests received which were unparseable and\n               which originated from `friends'.")
dnsServOptCounterFriendsOtherErrors = MibScalar((1, 3, 6, 1, 2, 1, 32, 1, 1, 3, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServOptCounterFriendsOtherErrors.setDescription("Number of requests which were aborted for other (local)\n               server errors and which originated from `friends'.")
dnsServZoneTable = MibTable((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1), )
if mibBuilder.loadTexts: dnsServZoneTable.setDescription("Table of zones for which this name server provides\n               information.  Each of the zones may be loaded from stable\n               storage via an implementation-specific mechanism or may\n               be obtained from another name server via a zone transfer.\n\n               If name server doesn't load any zones, this table is\n               empty.")
dnsServZoneEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1), ).setIndexNames((0, "DNS-SERVER-MIB", "dnsServZoneName"), (0, "DNS-SERVER-MIB", "dnsServZoneClass"))
if mibBuilder.loadTexts: dnsServZoneEntry.setDescription('An entry in the name server zone table.  New rows may be\n               added either via SNMP or by the name server itself.')
dnsServZoneName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 1), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsServZoneName.setDescription("DNS name of the zone described by this row of the table.\n               This is the owner name of the SOA RR that defines the\n               top of the zone. This is name is in uppercase:\n               characters 'a' through 'z' are mapped to 'A' through 'Z'\n               in order to make the lexical ordering useful.")
dnsServZoneClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 2), DnsClass())
if mibBuilder.loadTexts: dnsServZoneClass.setDescription('DNS class of the RRs in this zone.')
dnsServZoneLastReloadSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 3), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneLastReloadSuccess.setDescription('Elapsed time in seconds since last successful reload of\n               this zone.')
dnsServZoneLastReloadAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 4), DnsTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneLastReloadAttempt.setDescription('Elapsed time in seconds since last attempted reload of\n               this zone.')
dnsServZoneLastSourceAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneLastSourceAttempt.setDescription('IP address of host from which most recent zone transfer\n               of this zone was attempted.  This value should match the\n               value of dnsServZoneSourceSuccess if the attempt was\n               succcessful.  If zone transfer has not been attempted\n               within the memory of this name server, this value should\n               be 0.0.0.0.')
dnsServZoneStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsServZoneStatus.setDescription('The status of the information represented in this row of\n               the table.')
dnsServZoneSerial = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneSerial.setDescription('Zone serial number (from the SOA RR) of the zone\n               represented by this row of the table.  If the zone has\n               not been successfully loaded within the memory of this\n               name server, the value of this variable is zero.')
dnsServZoneCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneCurrent.setDescription("Whether the server's copy of the zone represented by\n               this row of the table is currently valid.  If the zone\n               has never been successfully loaded or has expired since\n               it was last succesfully loaded, this variable will have\n               the value false(2), otherwise this variable will have\n               the value true(1).")
dnsServZoneLastSourceSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 1, 1, 9), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dnsServZoneLastSourceSuccess.setDescription('IP address of host which was the source of the most\n               recent successful zone transfer for this zone.  If\n               unknown (e.g., zone has never been successfully\n               transfered) or irrelevant (e.g., zone was loaded from\n               stable storage), this value should be 0.0.0.0.')
dnsServZoneSrcTable = MibTable((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2), )
if mibBuilder.loadTexts: dnsServZoneSrcTable.setDescription('This table is a list of IP addresses from which the\n               server will attempt to load zone information using DNS\n               zone transfer operations.  A reload may occur due to SNMP\n               operations that create a row in dnsServZoneTable or a\n               SET to object dnsServZoneReload.  This table is only\n               used when the zone is loaded via zone transfer.')
dnsServZoneSrcEntry = MibTableRow((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2, 1), ).setIndexNames((0, "DNS-SERVER-MIB", "dnsServZoneSrcName"), (0, "DNS-SERVER-MIB", "dnsServZoneSrcClass"), (0, "DNS-SERVER-MIB", "dnsServZoneSrcAddr"))
if mibBuilder.loadTexts: dnsServZoneSrcEntry.setDescription('An entry in the name server zone source table.')
dnsServZoneSrcName = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2, 1, 1), DnsNameAsIndex())
if mibBuilder.loadTexts: dnsServZoneSrcName.setDescription('DNS name of the zone to which this entry applies.')
dnsServZoneSrcClass = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2, 1, 2), DnsClass())
if mibBuilder.loadTexts: dnsServZoneSrcClass.setDescription('DNS class of zone to which this entry applies.')
dnsServZoneSrcAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2, 1, 3), IpAddress())
if mibBuilder.loadTexts: dnsServZoneSrcAddr.setDescription('IP address of name server host from which this zone\n               might be obtainable.')
dnsServZoneSrcStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 32, 1, 1, 4, 2, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dnsServZoneSrcStatus.setDescription('The status of the information represented in this row of\n               the table.')
dnsServMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 2))
dnsServConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 1, 2, 1)).setObjects(*(("DNS-SERVER-MIB", "dnsServConfigImplementIdent"), ("DNS-SERVER-MIB", "dnsServConfigRecurs"), ("DNS-SERVER-MIB", "dnsServConfigUpTime"), ("DNS-SERVER-MIB", "dnsServConfigResetTime"), ("DNS-SERVER-MIB", "dnsServConfigReset"),))
if mibBuilder.loadTexts: dnsServConfigGroup.setDescription('A collection of objects providing basic configuration\n               control of a DNS name server.')
dnsServCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 1, 2, 2)).setObjects(*(("DNS-SERVER-MIB", "dnsServCounterAuthAns"), ("DNS-SERVER-MIB", "dnsServCounterAuthNoNames"), ("DNS-SERVER-MIB", "dnsServCounterAuthNoDataResps"), ("DNS-SERVER-MIB", "dnsServCounterNonAuthDatas"), ("DNS-SERVER-MIB", "dnsServCounterNonAuthNoDatas"), ("DNS-SERVER-MIB", "dnsServCounterReferrals"), ("DNS-SERVER-MIB", "dnsServCounterErrors"), ("DNS-SERVER-MIB", "dnsServCounterRelNames"), ("DNS-SERVER-MIB", "dnsServCounterReqRefusals"), ("DNS-SERVER-MIB", "dnsServCounterReqUnparses"), ("DNS-SERVER-MIB", "dnsServCounterOtherErrors"), ("DNS-SERVER-MIB", "dnsServCounterOpCode"), ("DNS-SERVER-MIB", "dnsServCounterQClass"), ("DNS-SERVER-MIB", "dnsServCounterQType"), ("DNS-SERVER-MIB", "dnsServCounterTransport"), ("DNS-SERVER-MIB", "dnsServCounterRequests"), ("DNS-SERVER-MIB", "dnsServCounterResponses"),))
if mibBuilder.loadTexts: dnsServCounterGroup.setDescription('A collection of objects providing basic instrumentation\n               of a DNS name server.')
dnsServOptCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 1, 2, 3)).setObjects(*(("DNS-SERVER-MIB", "dnsServOptCounterSelfAuthAns"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfAuthNoNames"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfAuthNoDataResps"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfNonAuthDatas"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfNonAuthNoDatas"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfReferrals"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfErrors"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfRelNames"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfReqRefusals"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfReqUnparses"), ("DNS-SERVER-MIB", "dnsServOptCounterSelfOtherErrors"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsAuthAns"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsAuthNoNames"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsAuthNoDataResps"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsNonAuthDatas"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsNonAuthNoDatas"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsReferrals"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsErrors"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsRelNames"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsReqRefusals"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsReqUnparses"), ("DNS-SERVER-MIB", "dnsServOptCounterFriendsOtherErrors"),))
if mibBuilder.loadTexts: dnsServOptCounterGroup.setDescription('A collection of objects providing extended\n               instrumentation of a DNS name server.')
dnsServZoneGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 32, 1, 2, 4)).setObjects(*(("DNS-SERVER-MIB", "dnsServZoneName"), ("DNS-SERVER-MIB", "dnsServZoneClass"), ("DNS-SERVER-MIB", "dnsServZoneLastReloadSuccess"), ("DNS-SERVER-MIB", "dnsServZoneLastReloadAttempt"), ("DNS-SERVER-MIB", "dnsServZoneLastSourceAttempt"), ("DNS-SERVER-MIB", "dnsServZoneLastSourceSuccess"), ("DNS-SERVER-MIB", "dnsServZoneStatus"), ("DNS-SERVER-MIB", "dnsServZoneSerial"), ("DNS-SERVER-MIB", "dnsServZoneCurrent"), ("DNS-SERVER-MIB", "dnsServZoneSrcName"), ("DNS-SERVER-MIB", "dnsServZoneSrcClass"), ("DNS-SERVER-MIB", "dnsServZoneSrcAddr"), ("DNS-SERVER-MIB", "dnsServZoneSrcStatus"),))
if mibBuilder.loadTexts: dnsServZoneGroup.setDescription('A collection of objects providing configuration control\n               of a DNS name server which loads authoritative zones.')
dnsServMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 32, 1, 3))
dnsServMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 32, 1, 3, 1)).setObjects(*(("DNS-SERVER-MIB", "dnsServConfigGroup"), ("DNS-SERVER-MIB", "dnsServCounterGroup"), ("DNS-SERVER-MIB", "dnsServOptCounterGroup"), ("DNS-SERVER-MIB", "dnsServZoneGroup"),))
if mibBuilder.loadTexts: dnsServMIBCompliance.setDescription('The compliance statement for agents implementing the DNS\n               name server MIB extensions.')
mibBuilder.exportSymbols("DNS-SERVER-MIB", dnsServOptCounterSelfAuthNoDataResps=dnsServOptCounterSelfAuthNoDataResps, dnsServMIBCompliances=dnsServMIBCompliances, dnsServOptCounterSelfAuthNoNames=dnsServOptCounterSelfAuthNoNames, dnsServOptCounterSelfReqUnparses=dnsServOptCounterSelfReqUnparses, dnsServConfig=dnsServConfig, dnsServCounterReqUnparses=dnsServCounterReqUnparses, dnsServOptCounterSelfRelNames=dnsServOptCounterSelfRelNames, DnsName=DnsName, dnsServConfigRecurs=dnsServConfigRecurs, dnsServCounterTable=dnsServCounterTable, dnsServCounterOtherErrors=dnsServCounterOtherErrors, dnsServOptCounterFriendsRelNames=dnsServOptCounterFriendsRelNames, dnsServOptCounterSelfNonAuthNoDatas=dnsServOptCounterSelfNonAuthNoDatas, dnsServZoneEntry=dnsServZoneEntry, dnsServOptCounterGroup=dnsServOptCounterGroup, dnsServCounterReqRefusals=dnsServCounterReqRefusals, dnsServZoneSrcEntry=dnsServZoneSrcEntry, DnsType=DnsType, dnsServZoneLastSourceAttempt=dnsServZoneLastSourceAttempt, dnsServCounter=dnsServCounter, dnsServCounterAuthAns=dnsServCounterAuthAns, dnsServCounterEntry=dnsServCounterEntry, dnsServZoneLastReloadSuccess=dnsServZoneLastReloadSuccess, dnsServZoneLastReloadAttempt=dnsServZoneLastReloadAttempt, dnsServCounterOpCode=dnsServCounterOpCode, dnsServZone=dnsServZone, dnsServConfigReset=dnsServConfigReset, dnsServOptCounterFriendsOtherErrors=dnsServOptCounterFriendsOtherErrors, dnsServZoneTable=dnsServZoneTable, DnsClass=DnsClass, dnsServCounterRelNames=dnsServCounterRelNames, dnsServConfigGroup=dnsServConfigGroup, dnsServCounterAuthNoDataResps=dnsServCounterAuthNoDataResps, dnsServCounterQClass=dnsServCounterQClass, dnsServZoneStatus=dnsServZoneStatus, dnsServMIB=dnsServMIB, PYSNMP_MODULE_ID=dnsServMIB, dnsServMIBObjects=dnsServMIBObjects, dnsServCounterReferrals=dnsServCounterReferrals, DnsQClass=DnsQClass, dnsServZoneSrcClass=dnsServZoneSrcClass, dnsServMIBGroups=dnsServMIBGroups, dnsServOptCounterSelfAuthAns=dnsServOptCounterSelfAuthAns, dnsServOptCounter=dnsServOptCounter, DnsOpCode=DnsOpCode, dnsServOptCounterFriendsNonAuthNoDatas=dnsServOptCounterFriendsNonAuthNoDatas, dnsServMIBCompliance=dnsServMIBCompliance, dnsServCounterRequests=dnsServCounterRequests, dnsServOptCounterSelfReferrals=dnsServOptCounterSelfReferrals, dnsServZoneSrcAddr=dnsServZoneSrcAddr, dns=dns, dnsServCounterNonAuthDatas=dnsServCounterNonAuthDatas, dnsServZoneCurrent=dnsServZoneCurrent, dnsServConfigResetTime=dnsServConfigResetTime, dnsServCounterErrors=dnsServCounterErrors, dnsServCounterQType=dnsServCounterQType, dnsServZoneSrcStatus=dnsServZoneSrcStatus, dnsServOptCounterFriendsAuthAns=dnsServOptCounterFriendsAuthAns, dnsServZoneGroup=dnsServZoneGroup, dnsServOptCounterFriendsNonAuthDatas=dnsServOptCounterFriendsNonAuthDatas, DnsQType=DnsQType, DnsRespCode=DnsRespCode, dnsServZoneClass=dnsServZoneClass, dnsServCounterNonAuthNoDatas=dnsServCounterNonAuthNoDatas, dnsServOptCounterSelfNonAuthDatas=dnsServOptCounterSelfNonAuthDatas, dnsServOptCounterFriendsErrors=dnsServOptCounterFriendsErrors, dnsServCounterResponses=dnsServCounterResponses, DnsNameAsIndex=DnsNameAsIndex, dnsServOptCounterFriendsReqRefusals=dnsServOptCounterFriendsReqRefusals, dnsServCounterGroup=dnsServCounterGroup, dnsServOptCounterSelfReqRefusals=dnsServOptCounterSelfReqRefusals, dnsServZoneLastSourceSuccess=dnsServZoneLastSourceSuccess, dnsServOptCounterSelfErrors=dnsServOptCounterSelfErrors, dnsServCounterTransport=dnsServCounterTransport, dnsServCounterAuthNoNames=dnsServCounterAuthNoNames, dnsServOptCounterSelfOtherErrors=dnsServOptCounterSelfOtherErrors, dnsServConfigUpTime=dnsServConfigUpTime, DnsTime=DnsTime, dnsServOptCounterFriendsAuthNoDataResps=dnsServOptCounterFriendsAuthNoDataResps, dnsServOptCounterFriendsReferrals=dnsServOptCounterFriendsReferrals, dnsServZoneName=dnsServZoneName, dnsServZoneSrcName=dnsServZoneSrcName, dnsServOptCounterFriendsAuthNoNames=dnsServOptCounterFriendsAuthNoNames, dnsServZoneSrcTable=dnsServZoneSrcTable, dnsServZoneSerial=dnsServZoneSerial, dnsServConfigImplementIdent=dnsServConfigImplementIdent, dnsServOptCounterFriendsReqUnparses=dnsServOptCounterFriendsReqUnparses)



#
# PySNMP MIB module IGMP-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IGMP-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:53 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ConstraintsUnion, ConstraintsIntersection, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueSizeConstraint")
( InterfaceIndex, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "InterfaceIndexOrZero")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( Counter32, IpAddress, Bits, Counter64, mib_2, TimeTicks, Integer32, NotificationType, ModuleIdentity, ObjectIdentity, Unsigned32, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "IpAddress", "Bits", "Counter64", "mib-2", "TimeTicks", "Integer32", "NotificationType", "ModuleIdentity", "ObjectIdentity", "Unsigned32", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "iso")
( DisplayString, TextualConvention, RowStatus, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "RowStatus", "TruthValue")
igmpStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 85)).setRevisions(("2000-09-28 00:00",))
if mibBuilder.loadTexts: igmpStdMIB.setLastUpdated('200009280000Z')
if mibBuilder.loadTexts: igmpStdMIB.setOrganization('IETF IDMR Working Group.')
if mibBuilder.loadTexts: igmpStdMIB.setContactInfo(' Dave Thaler\n              Microsoft Corporation\n              One Microsoft Way\n              Redmond, WA  98052-6399\n              US\n\n              Phone: +1 425 703 8835\n              EMail: dthaler@microsoft.com')
if mibBuilder.loadTexts: igmpStdMIB.setDescription('The MIB module for IGMP Management.')
igmpMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 85, 1))
igmpInterfaceTable = MibTable((1, 3, 6, 1, 2, 1, 85, 1, 1), )
if mibBuilder.loadTexts: igmpInterfaceTable.setDescription('The (conceptual) table listing the interfaces on which IGMP\n            is enabled.')
igmpInterfaceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 85, 1, 1, 1), ).setIndexNames((0, "IGMP-STD-MIB", "igmpInterfaceIfIndex"))
if mibBuilder.loadTexts: igmpInterfaceEntry.setDescription('An entry (conceptual row) representing an interface on\n            which IGMP is enabled.')
igmpInterfaceIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: igmpInterfaceIfIndex.setDescription('The ifIndex value of the interface for which IGMP is\n            enabled.')
igmpInterfaceQueryInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 2), Unsigned32().clone(125)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceQueryInterval.setDescription('The frequency at which IGMP Host-Query packets are\n            transmitted on this interface.')
igmpInterfaceStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceStatus.setDescription('The activation of a row enables IGMP on the interface.  The\n            destruction of a row disables IGMP on the interface.')
igmpInterfaceVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 4), Unsigned32().clone(2)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceVersion.setDescription('The version of IGMP which is running on this interface.\n            This object can be used to configure a router capable of\n            running either value.  For IGMP to function correctly, all\n            routers on a LAN must be configured to run the same version\n            of IGMP on that LAN.')
igmpInterfaceQuerier = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceQuerier.setDescription('The address of the IGMP Querier on the IP subnet to which\n            this interface is attached.')
igmpInterfaceQueryMaxResponseTime = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 6), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255)).clone(100)).setUnits('tenths of seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceQueryMaxResponseTime.setDescription('The maximum query response time advertised in IGMPv2\n            queries on this interface.')
igmpInterfaceQuerierUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 7), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceQuerierUpTime.setDescription('The time since igmpInterfaceQuerier was last changed.')
igmpInterfaceQuerierExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceQuerierExpiryTime.setDescription('The amount of time remaining before the Other Querier\n            Present Timer expires.  If the local system is the querier,\n            the value of this object is zero.')
igmpInterfaceVersion1QuerierTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 9), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceVersion1QuerierTimer.setDescription('The time remaining until the host assumes that there are no\n            IGMPv1 routers present on the interface.  While this is non-\n            zero, the host will reply to all queries with version 1\n            membership reports.')
igmpInterfaceWrongVersionQueries = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceWrongVersionQueries.setDescription('The number of queries received whose IGMP version does not\n            match igmpInterfaceVersion, over the lifetime of the row\n            entry.  IGMP requires that all routers on a LAN be\n            configured to run the same version of IGMP.  Thus, if any\n            queries are received with the wrong version, this indicates\n            a configuration error.')
igmpInterfaceJoins = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceJoins.setDescription('The number of times a group membership has been added on\n            this interface; that is, the number of times an entry for\n            this interface has been added to the Cache Table.  This\n            object gives an indication of the amount of IGMP activity\n            over the lifetime of the row entry.')
igmpInterfaceProxyIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 12), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceProxyIfIndex.setDescription('Some devices implement a form of IGMP proxying whereby\n            memberships learned on the interface represented by this\n            row, cause IGMP Host Membership Reports to be sent on the\n            interface whose ifIndex value is given by this object.  Such\n            a device would implement the igmpV2RouterMIBGroup only on\n            its router interfaces (those interfaces with non-zero\n            igmpInterfaceProxyIfIndex).  Typically, the value of this\n            object is 0, indicating that no proxying is being done.')
igmpInterfaceGroups = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpInterfaceGroups.setDescription('The current number of entries for this interface in the\n            Cache Table.')
igmpInterfaceRobustness = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 14), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,255)).clone(2)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceRobustness.setDescription('The Robustness Variable allows tuning for the expected\n            packet loss on a subnet.  If a subnet is expected to be\n            lossy, the Robustness Variable may be increased.  IGMP is\n            robust to (Robustness Variable-1) packet losses.')
igmpInterfaceLastMembQueryIntvl = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 1, 1, 15), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255)).clone(10)).setUnits('tenths of seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpInterfaceLastMembQueryIntvl.setDescription('The Last Member Query Interval is the Max Response Time\n            inserted into Group-Specific Queries sent in response to\n            Leave Group messages, and is also the amount of time between\n            Group-Specific Query messages.  This value may be tuned to\n            modify the leave latency of the network.  A reduced value\n            results in reduced time to detect the loss of the last\n            member of a group.  The value of this object is irrelevant\n            if igmpInterfaceVersion is 1.')
igmpCacheTable = MibTable((1, 3, 6, 1, 2, 1, 85, 1, 2), )
if mibBuilder.loadTexts: igmpCacheTable.setDescription('The (conceptual) table listing the IP multicast groups for\n            which there are members on a particular interface.')
igmpCacheEntry = MibTableRow((1, 3, 6, 1, 2, 1, 85, 1, 2, 1), ).setIndexNames((0, "IGMP-STD-MIB", "igmpCacheAddress"), (0, "IGMP-STD-MIB", "igmpCacheIfIndex"))
if mibBuilder.loadTexts: igmpCacheEntry.setDescription('An entry (conceptual row) in the igmpCacheTable.')
igmpCacheAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 1), IpAddress())
if mibBuilder.loadTexts: igmpCacheAddress.setDescription('The IP multicast group address for which this entry\n            contains information.')
igmpCacheIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 2), InterfaceIndex())
if mibBuilder.loadTexts: igmpCacheIfIndex.setDescription('The interface for which this entry contains information for\n            an IP multicast group address.')
igmpCacheSelf = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 3), TruthValue().clone('true')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpCacheSelf.setDescription('An indication of whether the local system is a member of\n            this group address on this interface.')
igmpCacheLastReporter = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 4), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpCacheLastReporter.setDescription('The IP address of the source of the last membership report\n            received for this IP Multicast group address on this\n            interface.  If no membership report has been received, this\n            object has the value 0.0.0.0.')
igmpCacheUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpCacheUpTime.setDescription('The time elapsed since this entry was created.')
igmpCacheExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 6), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpCacheExpiryTime.setDescription('The minimum amount of time remaining before this entry will\n            be aged out.  A value of 0 indicates that the entry is only\n            present because igmpCacheSelf is true and that if the router\n            left the group, this entry would be aged out immediately.\n            Note that some implementations may process membership\n            reports from the local system in the same way as reports\n            from other hosts, so a value of 0 is not required.')
igmpCacheStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: igmpCacheStatus.setDescription('The status of this entry.')
igmpCacheVersion1HostTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 85, 1, 2, 1, 8), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: igmpCacheVersion1HostTimer.setDescription('The time remaining until the local router will assume that\n            there are no longer any IGMP version 1 members on the IP\n            subnet attached to this interface.  Upon hearing any IGMPv1\n            Membership Report, this value is reset to the group\n            membership timer.  While this time remaining is non-zero,\n            the local router ignores any IGMPv2 Leave messages for this\n            group that it receives on this interface.')
igmpMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 85, 2))
igmpMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 85, 2, 1))
igmpMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 85, 2, 2))
igmpV1HostMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 85, 2, 1, 1)).setObjects(*(("IGMP-STD-MIB", "igmpBaseMIBGroup"),))
if mibBuilder.loadTexts: igmpV1HostMIBCompliance.setDescription('The compliance statement for hosts running IGMPv1 and\n            implementing the IGMP MIB.')
igmpV1RouterMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 85, 2, 1, 2)).setObjects(*(("IGMP-STD-MIB", "igmpBaseMIBGroup"), ("IGMP-STD-MIB", "igmpRouterMIBGroup"),))
if mibBuilder.loadTexts: igmpV1RouterMIBCompliance.setDescription('The compliance statement for routers running IGMPv1 and\n            implementing the IGMP MIB.')
igmpV2HostMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 85, 2, 1, 3)).setObjects(*(("IGMP-STD-MIB", "igmpBaseMIBGroup"), ("IGMP-STD-MIB", "igmpV2HostMIBGroup"),))
if mibBuilder.loadTexts: igmpV2HostMIBCompliance.setDescription('The compliance statement for hosts running IGMPv2 and\n            implementing the IGMP MIB.')
igmpV2RouterMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 85, 2, 1, 4)).setObjects(*(("IGMP-STD-MIB", "igmpBaseMIBGroup"), ("IGMP-STD-MIB", "igmpRouterMIBGroup"), ("IGMP-STD-MIB", "igmpV2RouterMIBGroup"),))
if mibBuilder.loadTexts: igmpV2RouterMIBCompliance.setDescription('The compliance statement for routers running IGMPv2 and\n            implementing the IGMP MIB.')
igmpBaseMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 1)).setObjects(*(("IGMP-STD-MIB", "igmpCacheSelf"), ("IGMP-STD-MIB", "igmpCacheStatus"), ("IGMP-STD-MIB", "igmpInterfaceStatus"),))
if mibBuilder.loadTexts: igmpBaseMIBGroup.setDescription('The basic collection of objects providing management of\n            IGMP version 1 or 2.')
igmpRouterMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 2)).setObjects(*(("IGMP-STD-MIB", "igmpCacheUpTime"), ("IGMP-STD-MIB", "igmpCacheExpiryTime"), ("IGMP-STD-MIB", "igmpInterfaceJoins"), ("IGMP-STD-MIB", "igmpInterfaceGroups"), ("IGMP-STD-MIB", "igmpCacheLastReporter"), ("IGMP-STD-MIB", "igmpInterfaceQuerierUpTime"), ("IGMP-STD-MIB", "igmpInterfaceQuerierExpiryTime"), ("IGMP-STD-MIB", "igmpInterfaceQueryInterval"),))
if mibBuilder.loadTexts: igmpRouterMIBGroup.setDescription('A collection of additional objects for management of IGMP\n            version 1 or 2 in routers.')
igmpV2HostMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 3)).setObjects(*(("IGMP-STD-MIB", "igmpInterfaceVersion1QuerierTimer"),))
if mibBuilder.loadTexts: igmpV2HostMIBGroup.setDescription('A collection of additional objects for management of IGMP\n            version 2 in hosts.')
igmpHostOptMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 4)).setObjects(*(("IGMP-STD-MIB", "igmpCacheLastReporter"), ("IGMP-STD-MIB", "igmpInterfaceQuerier"),))
if mibBuilder.loadTexts: igmpHostOptMIBGroup.setDescription('A collection of optional objects for IGMP hosts.\n            Supporting this group can be especially useful in an\n            environment with a router which does not support the IGMP\n            MIB.')
igmpV2RouterMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 5)).setObjects(*(("IGMP-STD-MIB", "igmpInterfaceVersion"), ("IGMP-STD-MIB", "igmpInterfaceQuerier"), ("IGMP-STD-MIB", "igmpInterfaceQueryMaxResponseTime"), ("IGMP-STD-MIB", "igmpInterfaceRobustness"), ("IGMP-STD-MIB", "igmpInterfaceWrongVersionQueries"), ("IGMP-STD-MIB", "igmpInterfaceLastMembQueryIntvl"), ("IGMP-STD-MIB", "igmpCacheVersion1HostTimer"),))
if mibBuilder.loadTexts: igmpV2RouterMIBGroup.setDescription('A collection of additional objects for management of IGMP\n            version 2 in routers.')
igmpV2ProxyMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 85, 2, 2, 6)).setObjects(*(("IGMP-STD-MIB", "igmpInterfaceProxyIfIndex"),))
if mibBuilder.loadTexts: igmpV2ProxyMIBGroup.setDescription('A collection of additional objects for management of IGMP\n            proxy devices.')
mibBuilder.exportSymbols("IGMP-STD-MIB", igmpInterfaceEntry=igmpInterfaceEntry, igmpMIBCompliances=igmpMIBCompliances, igmpInterfaceQueryMaxResponseTime=igmpInterfaceQueryMaxResponseTime, igmpInterfaceRobustness=igmpInterfaceRobustness, igmpMIBConformance=igmpMIBConformance, igmpInterfaceJoins=igmpInterfaceJoins, igmpInterfaceIfIndex=igmpInterfaceIfIndex, PYSNMP_MODULE_ID=igmpStdMIB, igmpCacheAddress=igmpCacheAddress, igmpCacheTable=igmpCacheTable, igmpInterfaceQueryInterval=igmpInterfaceQueryInterval, igmpCacheVersion1HostTimer=igmpCacheVersion1HostTimer, igmpV2HostMIBGroup=igmpV2HostMIBGroup, igmpStdMIB=igmpStdMIB, igmpInterfaceLastMembQueryIntvl=igmpInterfaceLastMembQueryIntvl, igmpInterfaceVersion1QuerierTimer=igmpInterfaceVersion1QuerierTimer, igmpCacheEntry=igmpCacheEntry, igmpV1RouterMIBCompliance=igmpV1RouterMIBCompliance, igmpInterfaceTable=igmpInterfaceTable, igmpInterfaceGroups=igmpInterfaceGroups, igmpCacheStatus=igmpCacheStatus, igmpBaseMIBGroup=igmpBaseMIBGroup, igmpHostOptMIBGroup=igmpHostOptMIBGroup, igmpCacheUpTime=igmpCacheUpTime, igmpCacheExpiryTime=igmpCacheExpiryTime, igmpV2HostMIBCompliance=igmpV2HostMIBCompliance, igmpMIBObjects=igmpMIBObjects, igmpV2ProxyMIBGroup=igmpV2ProxyMIBGroup, igmpInterfaceVersion=igmpInterfaceVersion, igmpMIBGroups=igmpMIBGroups, igmpV2RouterMIBCompliance=igmpV2RouterMIBCompliance, igmpInterfaceQuerierUpTime=igmpInterfaceQuerierUpTime, igmpInterfaceWrongVersionQueries=igmpInterfaceWrongVersionQueries, igmpInterfaceStatus=igmpInterfaceStatus, igmpRouterMIBGroup=igmpRouterMIBGroup, igmpCacheSelf=igmpCacheSelf, igmpInterfaceProxyIfIndex=igmpInterfaceProxyIfIndex, igmpV2RouterMIBGroup=igmpV2RouterMIBGroup, igmpCacheIfIndex=igmpCacheIfIndex, igmpCacheLastReporter=igmpCacheLastReporter, igmpInterfaceQuerierExpiryTime=igmpInterfaceQuerierExpiryTime, igmpInterfaceQuerier=igmpInterfaceQuerier, igmpV1HostMIBCompliance=igmpV1HostMIBCompliance)



#
# PySNMP MIB module T11-FC-VIRTUAL-FABRIC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-VIRTUAL-FABRIC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:38 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection", "SingleValueConstraint")
( FcNameIdOrZero, fcmPortEntry, fcmInstanceIndex, fcmSwitchEntry, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcNameIdOrZero", "fcmPortEntry", "fcmInstanceIndex", "fcmSwitchEntry")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ModuleIdentity, Counter64, mib_2, IpAddress, MibIdentifier, iso, Unsigned32, NotificationType, Gauge32, Counter32, TimeTicks, Integer32, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "ModuleIdentity", "Counter64", "mib-2", "IpAddress", "MibIdentifier", "iso", "Unsigned32", "NotificationType", "Gauge32", "Counter32", "TimeTicks", "Integer32", "ObjectIdentity")
( StorageType, RowStatus, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "StorageType", "RowStatus", "DisplayString", "TextualConvention")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcVirtualFabricMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 147)).setRevisions(("2006-11-10 00:00",))
if mibBuilder.loadTexts: t11FcVirtualFabricMIB.setLastUpdated('200611100000Z')
if mibBuilder.loadTexts: t11FcVirtualFabricMIB.setOrganization('IETF IMSS (Internet and Management Support\n                     for Storage) Working Group')
if mibBuilder.loadTexts: t11FcVirtualFabricMIB.setContactInfo('\n                     Scott Kipp\n                     McDATA Corporation\n                Tel: +1 720 558-3452\n             E-mail: scott.kipp@mcdata.com\n             Postal: 4 McDATA Parkway\n                     Broomfield, CO USA 80021\n\n                     G D Ramkumar\n                     SnapTell, Inc.\n                Tel: +1 650-326-7627\n             E-mail: gramkumar@stanfordalumni.org\n             Postal: 2741 Middlefield Rd, Suite 200\n                     Palo Alto, CA USA 94306\n\n                     Keith McCloghrie\n                     Cisco Systems, Inc.\n                Tel: +1 408 526-5260\n             E-mail: kzm@cisco.com\n             Postal: 170 West Tasman Drive\n                     San Jose, CA USA 95134\n            ')
if mibBuilder.loadTexts: t11FcVirtualFabricMIB.setDescription('This module defines management information specific to\n         Fibre Channel Virtual Fabrics.  A Virtual Fabric is a\n\n\n\n         Fabric composed of partitions of switches, links and\n         N_Ports with a single Fabric management domain, Fabric\n         Services and independence from other Virtual Fabrics.\n\n         Copyright (C) The IETF Trust (2006).  This version of\n         this MIB module is part of RFC 4747; see the RFC itself for\n         full legal notices.')
t11vfObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 147, 1))
t11vfConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 147, 2))
t11vfCoreSwitchTable = MibTable((1, 3, 6, 1, 2, 1, 147, 1, 1), )
if mibBuilder.loadTexts: t11vfCoreSwitchTable.setDescription('A table of core switches supported by the current\n         management entity.')
t11vfCoreSwitchEntry = MibTableRow((1, 3, 6, 1, 2, 1, 147, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-VIRTUAL-FABRIC-MIB", "t11vfCoreSwitchSwitchName"))
if mibBuilder.loadTexts: t11vfCoreSwitchEntry.setDescription('Each entry represents one core switch.')
t11vfCoreSwitchSwitchName = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 1, 1, 1), FcNameIdOrZero().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(8,8),ValueSizeConstraint(16,16),)))
if mibBuilder.loadTexts: t11vfCoreSwitchSwitchName.setDescription('The Core Switch_Name (WWN) of this Core Switch.')
t11vfCoreSwitchMaxSupported = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4095))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11vfCoreSwitchMaxSupported.setDescription('In switches that do not support Virtual Fabrics,\n         this object has the value of 1.  If Virtual Fabrics\n         are supported, this object is the maximum number of\n         Virtual Fabrics supported by the Core Switch.  For\n         the purpose of this count, the Control VF_ID is\n         ignored.')
t11vfCoreSwitchStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 1, 1, 3), StorageType().clone('nonVolatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11vfCoreSwitchStorageType.setDescription("The storage type for this conceptual row.\n         Conceptual rows having the value 'permanent' need not\n         allow write-access to any columnar objects in the row.")
t11vfVirtualSwitchTable = MibTable((1, 3, 6, 1, 2, 1, 147, 1, 2), )
if mibBuilder.loadTexts: t11vfVirtualSwitchTable.setDescription('A table of Virtual Switches.  When one Core Switch\n         provides switching functions for multiple Virtual Fabrics,\n         that Core Switch is modeled as containing multiple\n         Virtual Switches, one for each Virtual Fabric.  This table\n         contains one row for every Virtual Switch on every Core\n         Switch.  This table augments the basic switch information in\n         the fcmSwitchTable Table in the FC-MGMT-MIB.')
t11vfVirtualSwitchEntry = MibTableRow((1, 3, 6, 1, 2, 1, 147, 1, 2, 1), )
fcmSwitchEntry.registerAugmentions(("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfVirtualSwitchEntry"))
t11vfVirtualSwitchEntry.setIndexNames(*fcmSwitchEntry.getIndexNames())
if mibBuilder.loadTexts: t11vfVirtualSwitchEntry.setDescription('An entry of the Virtual Switch table.  Each row is for a\n         Virtual Switch.\n\n         This table augments the fcmSwitchTable, i.e., every entry\n         in this table has a one-to-one correspondence with an\n         entry in the fcmSwitchTable.  At the time when the\n         fcmSwitchTable was defined, it applied to physical\n         switches.  With the definition and usage of virtual\n         switches, fcmSwitchTable now applies to virtual switches\n         as well as physical switches, and (in contrast to physical\n         switches) it is appropriate to provide the capability for\n         virtual switches to be created via remote management\n         applications, e.g., via SNMP.\n\n         So, this entry contains a RowStatus object (to allow the\n         creation of a virtual switch), as well as a StorageType\n         object.  Obviously, if a row is created/deleted in this\n         table, the corresponding row in the fcmSwitchTable will\n         be created/deleted.')
t11vfVirtualSwitchVfId = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 2, 1, 1), T11FabricIndex()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11vfVirtualSwitchVfId.setDescription('The VF_ID of the Virtual Fabric for which this virtual\n         switch performs its switching function.  The Control\n         VF_ID is implicitly enabled and is not set.\n         Communication with the Control VF_ID is required.')
t11vfVirtualSwitchCoreSwitchName = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 2, 1, 2), FcNameIdOrZero().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(8,8),ValueSizeConstraint(16,16),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11vfVirtualSwitchCoreSwitchName.setDescription('The Core Switch_Name (WWN) of the Core Switch that\n         contains this Virtual Switch.')
t11vfVirtualSwitchRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11vfVirtualSwitchRowStatus.setDescription('The status of this row.')
t11vfVirtualSwitchStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 2, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11vfVirtualSwitchStorageType.setDescription("The storage type for this conceptual row.\n         Conceptual rows having the value 'permanent' need not\n         allow write-access to any columnar objects in the row.")
t11vfPortTable = MibTable((1, 3, 6, 1, 2, 1, 147, 1, 3), )
if mibBuilder.loadTexts: t11vfPortTable.setDescription('A table of Port attributes related to Virtual Fabrics.')
t11vfPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 147, 1, 3, 1), )
fcmPortEntry.registerAugmentions(("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfPortEntry"))
t11vfPortEntry.setIndexNames(*fcmPortEntry.getIndexNames())
if mibBuilder.loadTexts: t11vfPortEntry.setDescription('Each entry represents a physical Port on a switch.\n         Switches that support Virtual Fabrics would add\n\n\n\n         these four additional columns to the fcmPortEntry\n         row.')
t11vfPortVfId = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 3, 1, 1), T11FabricIndex().clone(1)).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11vfPortVfId.setDescription('The Port VF_ID assigned to this Port.  The Port VF_ID is the\n         default Virtual Fabric that is assigned to untagged frames\n         arriving at this Port.  The Control VF_ID is implicitly\n         enabled and is not set.  Communication with the Control\n         VF_ID is required.')
t11vfPortTaggingAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("off", 1), ("on", 2), ("auto", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11vfPortTaggingAdminStatus.setDescription("This object is used to configure the administrative status\n         of Virtual Fabric tagging on this Port.\n\n         SET operation   Description\n         --------------  -------------------------------------------\n         off(1)          To disable Virtual Fabric tagging on this\n                         Port.\n\n         on(2)           To enable Virtual Fabric tagging on this\n\n\n\n                         Port if the attached Port doesn't\n                         prohibit it.\n\n         auto(3)         To enable Virtual Fabric tagging if the\n                         peer requests it.")
t11vfPortTaggingOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("off", 1), ("on", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11vfPortTaggingOperStatus.setDescription('This object is used to report the operational status of\n         Virtual Fabric tagging on this Port.\n\n         SET operation   Description\n         --------------  -------------------------------------------\n         off(1)          Virtual Fabric tagging is disabled on this\n                         Port.\n\n         on(2)           Virtual Fabric tagging is enabled on this\n                         Port.')
t11vfPortStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 3, 1, 4), StorageType().clone('nonVolatile')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11vfPortStorageType.setDescription("The storage type for this conceptual row, and for the\n         corresponding row in the augmented fcmPortTable.\n\n         Conceptual rows having the value 'permanent' need not\n         allow write-access to any columnar objects in the row.")
t11vfLocallyEnabledTable = MibTable((1, 3, 6, 1, 2, 1, 147, 1, 4), )
if mibBuilder.loadTexts: t11vfLocallyEnabledTable.setDescription("A table for assigning and reporting operational status of\n         locally-enabled Virtual Fabric IDs to Ports.  The set of\n         Virtual Fabrics operational on the Port is the bit-wise\n         'AND' of the set of locally-enabled VF_IDs of this Port\n         and the locally-enabled VF_IDs of the attached Port.")
t11vfLocallyEnabledEntry = MibTableRow((1, 3, 6, 1, 2, 1, 147, 1, 4, 1), ).setIndexNames((0, "T11-FC-VIRTUAL-FABRIC-MIB", "t11vfLocallyEnabledPortIfIndex"), (0, "T11-FC-VIRTUAL-FABRIC-MIB", "t11vfLocallyEnabledVfId"))
if mibBuilder.loadTexts: t11vfLocallyEnabledEntry.setDescription('An entry for each locally-enabled VF_ID on\n         each Port.')
t11vfLocallyEnabledPortIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 4, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: t11vfLocallyEnabledPortIfIndex.setDescription('The value of the ifIndex that identifies the Port.')
t11vfLocallyEnabledVfId = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 4, 1, 2), T11FabricIndex())
if mibBuilder.loadTexts: t11vfLocallyEnabledVfId.setDescription('A locally-enabled VF_ID on this Port.')
t11vfLocallyEnabledOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 4, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("off", 1), ("on", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11vfLocallyEnabledOperStatus.setDescription('This object is used to report the operational status of\n         Virtual Fabric tagging on this Port.\n\n         SET operation   Description\n         --------------  -------------------------------------------\n         off(1)          Virtual Fabric tagging is disabled on this\n                         Port.\n\n         on(2)           Virtual Fabric tagging is enabled on this\n                         Port.')
t11vfLocallyEnabledRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 4, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11vfLocallyEnabledRowStatus.setDescription("The status of this conceptual row.\n\n             When a row in this table is in 'active(1)' state,\n             no object in that row can be modified except\n             t11vfLocallyEnabledRowStatus and\n             t11vfLocallyEnabledStorageType.")
t11vfLocallyEnabledStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 147, 1, 4, 1, 5), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11vfLocallyEnabledStorageType.setDescription("The storage type for this conceptual row.\n             Conceptual rows having the value 'permanent' need not\n             allow write-access to any columnar objects in the row.")
t11vfMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 147, 2, 1))
t11vfMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 147, 2, 2))
t11vfMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 147, 2, 1, 1)).setObjects(*(("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfGeneralGroup"),))
if mibBuilder.loadTexts: t11vfMIBCompliance.setDescription('Describes the requirements for compliance to the\n         Fibre Channel Virtual Fabric MIB.')
t11vfGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 147, 2, 2, 1)).setObjects(*(("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfCoreSwitchMaxSupported"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfVirtualSwitchVfId"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfVirtualSwitchCoreSwitchName"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfVirtualSwitchRowStatus"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfPortVfId"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfPortTaggingAdminStatus"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfLocallyEnabledOperStatus"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfPortTaggingOperStatus"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfLocallyEnabledRowStatus"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfCoreSwitchStorageType"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfVirtualSwitchStorageType"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfPortStorageType"), ("T11-FC-VIRTUAL-FABRIC-MIB", "t11vfLocallyEnabledStorageType"),))
if mibBuilder.loadTexts: t11vfGeneralGroup.setDescription('A collection of objects for monitoring and\n             configuring Virtual Fabrics in a Fibre Channel switch.')
mibBuilder.exportSymbols("T11-FC-VIRTUAL-FABRIC-MIB", t11vfPortTaggingAdminStatus=t11vfPortTaggingAdminStatus, t11vfLocallyEnabledStorageType=t11vfLocallyEnabledStorageType, t11vfVirtualSwitchEntry=t11vfVirtualSwitchEntry, t11vfGeneralGroup=t11vfGeneralGroup, t11vfVirtualSwitchTable=t11vfVirtualSwitchTable, t11vfLocallyEnabledOperStatus=t11vfLocallyEnabledOperStatus, t11vfCoreSwitchStorageType=t11vfCoreSwitchStorageType, PYSNMP_MODULE_ID=t11FcVirtualFabricMIB, t11vfObjects=t11vfObjects, t11vfMIBGroups=t11vfMIBGroups, t11vfPortEntry=t11vfPortEntry, t11vfPortTable=t11vfPortTable, t11vfLocallyEnabledVfId=t11vfLocallyEnabledVfId, t11vfMIBCompliances=t11vfMIBCompliances, t11FcVirtualFabricMIB=t11FcVirtualFabricMIB, t11vfPortTaggingOperStatus=t11vfPortTaggingOperStatus, t11vfPortStorageType=t11vfPortStorageType, t11vfLocallyEnabledTable=t11vfLocallyEnabledTable, t11vfLocallyEnabledPortIfIndex=t11vfLocallyEnabledPortIfIndex, t11vfConformance=t11vfConformance, t11vfVirtualSwitchStorageType=t11vfVirtualSwitchStorageType, t11vfLocallyEnabledRowStatus=t11vfLocallyEnabledRowStatus, t11vfVirtualSwitchCoreSwitchName=t11vfVirtualSwitchCoreSwitchName, t11vfVirtualSwitchVfId=t11vfVirtualSwitchVfId, t11vfCoreSwitchTable=t11vfCoreSwitchTable, t11vfMIBCompliance=t11vfMIBCompliance, t11vfCoreSwitchSwitchName=t11vfCoreSwitchSwitchName, t11vfLocallyEnabledEntry=t11vfLocallyEnabledEntry, t11vfCoreSwitchEntry=t11vfCoreSwitchEntry, t11vfCoreSwitchMaxSupported=t11vfCoreSwitchMaxSupported, t11vfPortVfId=t11vfPortVfId, t11vfVirtualSwitchRowStatus=t11vfVirtualSwitchRowStatus)
